/*****************************************************************************************
*                                                                                        *
* This SAS program will extract the United States Sentencing Commission's fiscal year    *
* 2022 Organizational file and create a SAS dataset.                                     *
*                                                                                        *
* Prior to running the program you must update the DAT file location in the FILNAME line *
* to correspond to the location of the file on your computer, replacing the '.' with the *
* folder path location (e.g. 'C:\temp') .                                                *
*                                                                                        *
* You must also update the library location in the LIBNAME statement to correspond to    *
* the folder you want the output file to be located, replacing the '.' with the folder   *
* path location (e.g. 'C:\temp') .                                                       *
*                                                                                        *
*****************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
FILENAME datafile '.\corp22nid.dat' ;

/* The following line should contain the directory in which you wish your SAS file to be stored */
libname library '.' ;

/* The following line contains the name (without the extension) for your SAS dataset */
%LET dataset = corp22nid ;

DATA library.&dataset ;
INFILE datafile LRECL=2885;
INPUT
   ACCEPT  1-2              BUSCLAS  3-6             CANTPAY  7            
   CCULPSCO  8              CH2APP  9                CH8FINGD  10          
   CMSRVORD  11             COFI  12                 COMPLY  13            
   COMPLYPR  14             CRIMPURP  15             DETBFINE  16          
   DISPOSIT  17             EMPLOYNM  18             FCULPSCO  19          
   FRAUDTYP  20-21          FINSTDS  22              HISTORY  23           
   HSMISCND  24             INCORLOC  25             INCORPYR  26-29       
   INDICT  30               INPLEA1  31              INPLEA2  32           
   INPLEA3  33              INPLEA4  34              INPLEA5  35           
   INPLEA6  36              INPLEA7  37              INPLEA8  38           
   INPLEA9  39              INPLEA10  40             INPLEA11  41          
   INPLEA12  42             INNOPL1  43              INNOPL2  44           
   INNOPL3  45              INNOPL4  46              INNOPL5  47           
   INNOPL6  48              INNOPL7  49              INNOPL8  50           
   INNOPL9  51              INNOPL10  52             INNOPL11  53          
   INNOPL12  54             JANDC  55                NEWCNVTN  56          
   NOCOMP  57               NOCOUNTS  58-59          NOREAVAR  60          
   NOUSTAT  61              OBSTRUCT  62             OFFLVL  63-64         
   ORDERCE  65              OWNSTRCT  66             PLEA  67              
   PRIMOFF  68-69           PRCIVIL  70              PRCRIME  71           
   PROBATN  72-73           PROBMON  74              PSR  75               
   QUARTER  76              REAS1  77-79             REAS2  80             
   REAS3  81-82             REASON2  83              REASON3  84           
   REASON4  85              REASONS  86              REMEDORD  87          
   SELFREP  88              SENTRNGE  89             TOLERNCE  90          
   TYPEOTHS  91-92          VICTNOTE  93             VIOLATE  94           
   AMENDYR  95-98           SENTYR  99-102           BASEFINE  103-111     
   COSTASSM  112-115        DISGORGE  116            FINOFFST  117         
   FORFEITR  118-126        GLFINMAX  127-135        GLFINMIN  136-144     
   STATMIN  145             STATMAX  146-153         RESTCAT  154          
   FINECAT  155             SUSFNCAT  156            LCAT1  157            
   LCAT2  158               LCAT3  159               LCATHI  160           
   LCATS1  161              LCATS2  162              LCATS3  163           
   LCATSHI  164             LCATR1  165              LCATR2  166           
   LCATR3  167              LCATRHI  168             LCATC1  169           
   LCATC2  170              LCATC3  171              LCATCHI  172          
   LCATU1  173              LCATU2  174              LCATU3  175           
   LCATUHI  176             CPIDN  177-183           BUSTEXT $ 184         
   FINSTXT $ 185            OWNSTEXT $ 186           PRMONTXT $ 187-278    
   ORDERTXT $ 279-463       TYPEOTTX $ 464-644       MINFINML  645-648     
   MAXFINML  649-651        ADJOFL1  652-653         ADJOFL2  654-655      
   ADJOFL3  656-657         ADJOFLHI  658-659        ADJ_B1  660-661       
   ADJ_B2  662              ADJ_B3  663-664          ADJ_BHI  665-666      
   ADJ_C1  667              ADJ_C2  668              ADJ_C3  669           
   ADJ_CHI  670             ADJ_D1  671              ADJ_D2  672           
   ADJ_D3  673              ADJ_DHI  674             ADJ_E1  675           
   ADJ_E2  676              ADJ_E3  677              ADJ_EHI  678          
   ADJ_F1  679              ADJ_F2  680              ADJ_F3  681           
   ADJ_FHI  682             ADJ_G1  683              ADJ_G2  684           
   ADJ_G3  685              ADJ_GHI  686             ADJ_H1  687           
   ADJ_H2  688              ADJ_H3  689              ADJ_HHI  690          
   ADJ_I1  691              ADJ_I2  692              ADJ_I3  693           
   ADJ_IHI  694             ADJ_J1  695              ADJ_J2  696           
   ADJ_J3  697              ADJ_JHI  698             ADJ_K1  699           
   ADJ_K2  700              ADJ_K3  701              ADJ_KHI  702          
   ADJ_L1  703              ADJ_L2  704              ADJ_L3  705           
   ADJ_LHI  706             ADJ_M1  707              ADJ_M2  708           
   ADJ_M3  709              ADJ_MHI  710             ADJ_N1  711           
   ADJ_N2  712              ADJ_N3  713              ADJ_NHI  714          
   ADJ_O1  715              ADJ_O2  716              ADJ_O3  717           
   ADJ_OHI  718             ADJ_P1  719              ADJ_P2  720           
   ADJ_P3  721              ADJ_PHI  722             ADJ_Q1  723           
   ADJ_Q2  724              ADJ_Q3  725              ADJ_QHI  726          
   ADJ_R1  727              ADJ_R2  728              ADJ_R3  729           
   ADJ_RHI  730             ADJ_S1  731              ADJ_S2  732           
   ADJ_S3  733              ADJ_SHI  734             ADJ_T1  735           
   ADJ_T2  736              ADJ_T3  737              ADJ_THI  738          
   ADJ_U1  739              ADJ_U2  740              ADJ_U3  741           
   ADJ_UHI  742             BASADJ1  743             BASADJ2  744          
   BASADJ3  745             BASADJHI  746            BASE1  747-748        
   BASE2  749-750           BASE3  751               BASEHI  752-753       
   BASLN1  754              BASLN2  755              BASLN3  756           
   BASLNHI  757             ADJOFS1  758-759         ADJOFS2  760-761      
   ADJOFS3  762-763         ADJOFSHI  764-765        ADJS_B1  766-767      
   ADJS_B2  768             ADJS_B3  769-770         ADJS_BHI  771-772     
   ADJS_C1  773             ADJS_C2  774             ADJS_C3  775          
   ADJS_CHI  776            ADJS_D1  777             ADJS_D2  778          
   ADJS_D3  779             ADJS_DHI  780            ADJS_E1  781          
   ADJS_E2  782             ADJS_E3  783             ADJS_EHI  784         
   ADJS_F1  785             ADJS_F2  786             ADJS_F3  787          
   ADJS_FHI  788            ADJS_G1  789             ADJS_G2  790          
   ADJS_G3  791             ADJS_GHI  792            ADJS_H1  793          
   ADJS_H2  794             ADJS_H3  795             ADJS_HHI  796         
   ADJS_I1  797             ADJS_I2  798             ADJS_I3  799          
   ADJS_IHI  800            ADJS_J1  801             ADJS_J2  802          
   ADJS_J3  803             ADJS_JHI  804            ADJS_K1  805          
   ADJS_K2  806             ADJS_K3  807             ADJS_KHI  808         
   ADJS_L1  809             ADJS_L2  810             ADJS_L3  811          
   ADJS_LHI  812            ADJS_M1  813             ADJS_M2  814          
   ADJS_M3  815             ADJS_MHI  816            ADJS_N1  817          
   ADJS_N2  818             ADJS_N3  819             ADJS_NHI  820         
   ADJS_O1  821             ADJS_O2  822             ADJS_O3  823          
   ADJS_OHI  824            ADJS_P1  825             ADJS_P2  826          
   ADJS_P3  827             ADJS_PHI  828            ADJS_Q1  829          
   ADJS_Q2  830             ADJS_Q3  831             ADJS_QHI  832         
   ADJS_R1  833             ADJS_R2  834             ADJS_R3  835          
   ADJS_RHI  836            ADJS_S1  837             ADJS_S2  838          
   ADJS_S3  839             ADJS_SHI  840            ADJS_T1  841          
   ADJS_T2  842             ADJS_T3  843             ADJS_THI  844         
   ADJS_U1  845             ADJS_U2  846             ADJS_U3  847          
   ADJS_UHI  848            BASADS1  849             BASADS2  850          
   BASADS3  851             BASADSHI  852            BASES1  853-854       
   BASES2  855-856          BASES3  857              BASESHI  858-859      
   BASLNS1  860             BASLNS2  861             BASLNS3  862          
   BASLNSHI  863            ADJOFR1  864-865         ADJOFR2  866-867      
   ADJOFR3  868             ADJOFRHI  869-870        ADJR_B1  871-872      
   ADJR_B2  873-874         ADJR_B3  875             ADJR_BHI  876-877     
   ADJR_C1  878             ADJR_C2  879             ADJR_C3  880          
   ADJR_CHI  881            ADJR_D1  882             ADJR_D2  883          
   ADJR_D3  884             ADJR_DHI  885            ADJR_E1  886          
   ADJR_E2  887             ADJR_E3  888             ADJR_EHI  889         
   ADJR_F1  890             ADJR_F2  891             ADJR_F3  892          
   ADJR_FHI  893            ADJR_G1  894             ADJR_G2  895          
   ADJR_G3  896             ADJR_GHI  897            ADJR_H1  898          
   ADJR_H2  899             ADJR_H3  900             ADJR_HHI  901         
   ADJR_I1  902             ADJR_I2  903             ADJR_I3  904          
   ADJR_IHI  905            ADJR_J1  906             ADJR_J2  907          
   ADJR_J3  908             ADJR_JHI  909            ADJR_K1  910          
   ADJR_K2  911             ADJR_K3  912             ADJR_KHI  913         
   ADJR_L1  914             ADJR_L2  915             ADJR_L3  916          
   ADJR_LHI  917            ADJR_M1  918             ADJR_M2  919          
   ADJR_M3  920             ADJR_MHI  921            ADJR_N1  922          
   ADJR_N2  923             ADJR_N3  924             ADJR_NHI  925         
   ADJR_O1  926             ADJR_O2  927             ADJR_O3  928          
   ADJR_OHI  929            ADJR_P1  930             ADJR_P2  931          
   ADJR_P3  932             ADJR_PHI  933            ADJR_Q1  934          
   ADJR_Q2  935             ADJR_Q3  936             ADJR_QHI  937         
   ADJR_R1  938             ADJR_R2  939             ADJR_R3  940          
   ADJR_RHI  941            ADJR_S1  942             ADJR_S2  943          
   ADJR_S3  944             ADJR_SHI  945            ADJR_T1  946          
   ADJR_T2  947             ADJR_T3  948             ADJR_THI  949         
   ADJR_U1  950             ADJR_U2  951             ADJR_U3  952          
   ADJR_UHI  953            BASADR1  954             BASADR2  955          
   BASADR3  956             BASADRHI  957            BASER1  958-959       
   BASER2  960              BASER3  961              BASERHI  962-963      
   BASLNR1  964             BASLNR2  965             BASLNR3  966          
   BASLNRHI  967            ADJOFC1  968             ADJOFC2  969          
   ADJOFC3  970             ADJOFCHI  971            ADJC_B1  972          
   ADJC_B2  973             ADJC_B3  974             ADJC_BHI  975         
   ADJC_C1  976             ADJC_C2  977             ADJC_C3  978          
   ADJC_CHI  979            ADJC_D1  980             ADJC_D2  981          
   ADJC_D3  982             ADJC_DHI  983            ADJC_E1  984          
   ADJC_E2  985             ADJC_E3  986             ADJC_EHI  987         
   ADJC_F1  988             ADJC_F2  989             ADJC_F3  990          
   ADJC_FHI  991            ADJC_G1  992             ADJC_G2  993          
   ADJC_G3  994             ADJC_GHI  995            ADJC_H1  996          
   ADJC_H2  997             ADJC_H3  998             ADJC_HHI  999         
   ADJC_I1  1000            ADJC_I2  1001            ADJC_I3  1002         
   ADJC_IHI  1003           ADJC_J1  1004            ADJC_J2  1005         
   ADJC_J3  1006            ADJC_JHI  1007           ADJC_K1  1008         
   ADJC_K2  1009            ADJC_K3  1010            ADJC_KHI  1011        
   ADJC_L1  1012            ADJC_L2  1013            ADJC_L3  1014         
   ADJC_LHI  1015           ADJC_M1  1016            ADJC_M2  1017         
   ADJC_M3  1018            ADJC_MHI  1019           ADJC_N1  1020         
   ADJC_N2  1021            ADJC_N3  1022            ADJC_NHI  1023        
   ADJC_O1  1024            ADJC_O2  1025            ADJC_O3  1026         
   ADJC_OHI  1027           ADJC_P1  1028            ADJC_P2  1029         
   ADJC_P3  1030            ADJC_PHI  1031           ADJC_Q1  1032         
   ADJC_Q2  1033            ADJC_Q3  1034            ADJC_QHI  1035        
   ADJC_R1  1036            ADJC_R2  1037            ADJC_R3  1038         
   ADJC_RHI  1039           ADJC_S1  1040            ADJC_S2  1041         
   ADJC_S3  1042            ADJC_SHI  1043           ADJC_T1  1044         
   ADJC_T2  1045            ADJC_T3  1046            ADJC_THI  1047        
   ADJC_U1  1048            ADJC_U2  1049            ADJC_U3  1050         
   ADJC_UHI  1051           BASADC1  1052            BASADC2  1053         
   BASADC3  1054            BASADCHI  1055           BASEC1  1056          
   BASEC2  1057             BASEC3  1058             BASECHI  1059         
   BASLNC1  1060            BASLNC2  1061            BASLNC3  1062         
   BASLNCHI  1063           ADJOFU1  1064            ADJOFU2  1065         
   ADJOFU3  1066            ADJOFUHI  1067           ADJU_B1  1068         
   ADJU_B2  1069            ADJU_B3  1070            ADJU_BHI  1071        
   ADJU_C1  1072            ADJU_C2  1073            ADJU_C3  1074         
   ADJU_CHI  1075           ADJU_D1  1076            ADJU_D2  1077         
   ADJU_D3  1078            ADJU_DHI  1079           ADJU_E1  1080         
   ADJU_E2  1081            ADJU_E3  1082            ADJU_EHI  1083        
   ADJU_F1  1084            ADJU_F2  1085            ADJU_F3  1086         
   ADJU_FHI  1087           ADJU_G1  1088            ADJU_G2  1089         
   ADJU_G3  1090            ADJU_GHI  1091           ADJU_H1  1092         
   ADJU_H2  1093            ADJU_H3  1094            ADJU_HHI  1095        
   ADJU_I1  1096            ADJU_I2  1097            ADJU_I3  1098         
   ADJU_IHI  1099           ADJU_J1  1100            ADJU_J2  1101         
   ADJU_J3  1102            ADJU_JHI  1103           ADJU_K1  1104         
   ADJU_K2  1105            ADJU_K3  1106            ADJU_KHI  1107        
   ADJU_L1  1108            ADJU_L2  1109            ADJU_L3  1110         
   ADJU_LHI  1111           ADJU_M1  1112            ADJU_M2  1113         
   ADJU_M3  1114            ADJU_MHI  1115           ADJU_N1  1116         
   ADJU_N2  1117            ADJU_N3  1118            ADJU_NHI  1119        
   ADJU_O1  1120            ADJU_O2  1121            ADJU_O3  1122         
   ADJU_OHI  1123           ADJU_P1  1124            ADJU_P2  1125         
   ADJU_P3  1126            ADJU_PHI  1127           ADJU_Q1  1128         
   ADJU_Q2  1129            ADJU_Q3  1130            ADJU_QHI  1131        
   ADJU_R1  1132            ADJU_R2  1133            ADJU_R3  1134         
   ADJU_RHI  1135           ADJU_S1  1136            ADJU_S2  1137         
   ADJU_S3  1138            ADJU_SHI  1139           ADJU_T1  1140         
   ADJU_T2  1141            ADJU_T3  1142            ADJU_THI  1143        
   ADJU_U1  1144            ADJU_U2  1145            ADJU_U3  1146         
   ADJU_UHI  1147           BASADU1  1148            BASADU2  1149         
   BASADU3  1150            BASADUHI  1151           BASEU1  1152          
   BASEU2  1153             BASEU3  1154             BASEUHI  1155         
   BASLNU1  1156            BASLNU2  1157            BASLNU3  1158         
   BASLNUHI  1159           ADJL_B1 $ 1160           ADJL_B2 $ 1161        
   ADJL_B3 $ 1162           ADJL_BHI $ 1163          ADJL_C1 $ 1164-1165   
   ADJL_C2 $ 1166           ADJL_C3 $ 1167           ADJL_CHI $ 1168-1169  
   ADJL_D1 $ 1170           ADJL_D2 $ 1171           ADJL_D3 $ 1172        
   ADJL_DHI $ 1173          ADJL_E1 $ 1174           ADJL_E2 $ 1175        
   ADJL_E3 $ 1176           ADJL_EHI $ 1177          ADJL_F1 $ 1178        
   ADJL_F2 $ 1179           ADJL_F3 $ 1180           ADJL_FHI $ 1181       
   ADJL_G1 $ 1182           ADJL_G2 $ 1183           ADJL_G3 $ 1184        
   ADJL_GHI $ 1185          ADJL_H1 $ 1186-1187      ADJL_H2 $ 1188        
   ADJL_H3 $ 1189           ADJL_HHI $ 1190-1191     ADJL_I1 $ 1192        
   ADJL_I2 $ 1193           ADJL_I3 $ 1194           ADJL_IHI $ 1195       
   ADJL_J1 $ 1196           ADJL_J2 $ 1197           ADJL_J3 $ 1198        
   ADJL_JHI $ 1199          ADJL_K1 $ 1200           ADJL_K2 $ 1201        
   ADJL_K3 $ 1202           ADJL_KHI $ 1203          ADJL_L1 $ 1204        
   ADJL_L2 $ 1205           ADJL_L3 $ 1206           ADJL_LHI $ 1207       
   ADJL_M1 $ 1208           ADJL_M2 $ 1209           ADJL_M3 $ 1210        
   ADJL_MHI $ 1211          ADJL_N1 $ 1212           ADJL_N2 $ 1213        
   ADJL_N3 $ 1214           ADJL_NHI $ 1215          ADJL_O1 $ 1216        
   ADJL_O2 $ 1217           ADJL_O3 $ 1218           ADJL_OHI $ 1219       
   ADJL_P1 $ 1220           ADJL_P2 $ 1221           ADJL_P3 $ 1222        
   ADJL_PHI $ 1223          ADJL_Q1 $ 1224           ADJL_Q2 $ 1225        
   ADJL_Q3 $ 1226           ADJL_QHI $ 1227          ADJL_R1 $ 1228        
   ADJL_R2 $ 1229           ADJL_R3 $ 1230           ADJL_RHI $ 1231       
   ADJL_S1 $ 1232           ADJL_S2 $ 1233           ADJL_S3 $ 1234        
   ADJL_SHI $ 1235          ADJL_T1 $ 1236           ADJL_T2 $ 1237        
   ADJL_T3 $ 1238           ADJL_THI $ 1239          ADJL_U1 $ 1240-1241   
   ADJL_U2 $ 1242           ADJL_U3 $ 1243           ADJL_UHI $ 1244-1245  
   BASEL1 $ 1246            BASEL2 $ 1247            BASEL3 $ 1248         
   BASELHI $ 1249           ADSL_B1 $ 1250           ADSL_B2 $ 1251        
   ADSL_B3 $ 1252           ADSL_BHI $ 1253          ADSL_C1 $ 1254-1255   
   ADSL_C2 $ 1256           ADSL_C3 $ 1257           ADSL_CHI $ 1258-1259  
   ADSL_D1 $ 1260           ADSL_D2 $ 1261           ADSL_D3 $ 1262        
   ADSL_DHI $ 1263          ADSL_E1 $ 1264           ADSL_E2 $ 1265        
   ADSL_E3 $ 1266           ADSL_EHI $ 1267          ADSL_F1 $ 1268        
   ADSL_F2 $ 1269           ADSL_F3 $ 1270           ADSL_FHI $ 1271       
   ADSL_G1 $ 1272           ADSL_G2 $ 1273           ADSL_G3 $ 1274        
   ADSL_GHI $ 1275          ADSL_H1 $ 1276-1277      ADSL_H2 $ 1278        
   ADSL_H3 $ 1279           ADSL_HHI $ 1280-1281     ADSL_I1 $ 1282        
   ADSL_I2 $ 1283           ADSL_I3 $ 1284           ADSL_IHI $ 1285       
   ADSL_J1 $ 1286           ADSL_J2 $ 1287           ADSL_J3 $ 1288        
   ADSL_JHI $ 1289          ADSL_K1 $ 1290           ADSL_K2 $ 1291        
   ADSL_K3 $ 1292           ADSL_KHI $ 1293          ADSL_L1 $ 1294        
   ADSL_L2 $ 1295           ADSL_L3 $ 1296           ADSL_LHI $ 1297       
   ADSL_M1 $ 1298           ADSL_M2 $ 1299           ADSL_M3 $ 1300        
   ADSL_MHI $ 1301          ADSL_N1 $ 1302           ADSL_N2 $ 1303        
   ADSL_N3 $ 1304           ADSL_NHI $ 1305          ADSL_O1 $ 1306        
   ADSL_O2 $ 1307           ADSL_O3 $ 1308           ADSL_OHI $ 1309       
   ADSL_P1 $ 1310           ADSL_P2 $ 1311           ADSL_P3 $ 1312        
   ADSL_PHI $ 1313          ADSL_Q1 $ 1314           ADSL_Q2 $ 1315        
   ADSL_Q3 $ 1316           ADSL_QHI $ 1317          ADSL_R1 $ 1318        
   ADSL_R2 $ 1319           ADSL_R3 $ 1320           ADSL_RHI $ 1321       
   ADSL_S1 $ 1322           ADSL_S2 $ 1323           ADSL_S3 $ 1324        
   ADSL_SHI $ 1325          ADSL_T1 $ 1326           ADSL_T2 $ 1327        
   ADSL_T3 $ 1328           ADSL_THI $ 1329          ADSL_U1 $ 1330-1331   
   ADSL_U2 $ 1332           ADSL_U3 $ 1333           ADSL_UHI $ 1334-1335  
   BASESL1 $ 1336           BASESL2 $ 1337           BASESL3 $ 1338        
   BASESLHI $ 1339          ADRL_B1 $ 1340           ADRL_B2 $ 1341        
   ADRL_B3 $ 1342           ADRL_BHI $ 1343          ADRL_C1 $ 1344-1345   
   ADRL_C2 $ 1346           ADRL_C3 $ 1347           ADRL_CHI $ 1348-1349  
   ADRL_D1 $ 1350           ADRL_D2 $ 1351           ADRL_D3 $ 1352        
   ADRL_DHI $ 1353          ADRL_E1 $ 1354           ADRL_E2 $ 1355        
   ADRL_E3 $ 1356           ADRL_EHI $ 1357          ADRL_F1 $ 1358        
   ADRL_F2 $ 1359           ADRL_F3 $ 1360           ADRL_FHI $ 1361       
   ADRL_G1 $ 1362           ADRL_G2 $ 1363           ADRL_G3 $ 1364        
   ADRL_GHI $ 1365          ADRL_H1 $ 1366           ADRL_H2 $ 1367        
   ADRL_H3 $ 1368           ADRL_HHI $ 1369          ADRL_I1 $ 1370        
   ADRL_I2 $ 1371           ADRL_I3 $ 1372           ADRL_IHI $ 1373       
   ADRL_J1 $ 1374           ADRL_J2 $ 1375           ADRL_J3 $ 1376        
   ADRL_JHI $ 1377          ADRL_K1 $ 1378           ADRL_K2 $ 1379        
   ADRL_K3 $ 1380           ADRL_KHI $ 1381          ADRL_L1 $ 1382        
   ADRL_L2 $ 1383           ADRL_L3 $ 1384           ADRL_LHI $ 1385       
   ADRL_M1 $ 1386           ADRL_M2 $ 1387           ADRL_M3 $ 1388        
   ADRL_MHI $ 1389          ADRL_N1 $ 1390           ADRL_N2 $ 1391        
   ADRL_N3 $ 1392           ADRL_NHI $ 1393          ADRL_O1 $ 1394        
   ADRL_O2 $ 1395           ADRL_O3 $ 1396           ADRL_OHI $ 1397       
   ADRL_P1 $ 1398           ADRL_P2 $ 1399           ADRL_P3 $ 1400        
   ADRL_PHI $ 1401          ADRL_Q1 $ 1402           ADRL_Q2 $ 1403        
   ADRL_Q3 $ 1404           ADRL_QHI $ 1405          ADRL_R1 $ 1406        
   ADRL_R2 $ 1407           ADRL_R3 $ 1408           ADRL_RHI $ 1409       
   ADRL_S1 $ 1410           ADRL_S2 $ 1411           ADRL_S3 $ 1412        
   ADRL_SHI $ 1413          ADRL_T1 $ 1414           ADRL_T2 $ 1415        
   ADRL_T3 $ 1416           ADRL_THI $ 1417          ADRL_U1 $ 1418        
   ADRL_U2 $ 1419           ADRL_U3 $ 1420           ADRL_UHI $ 1421       
   BASERL1 $ 1422           BASERL2 $ 1423           BASERL3 $ 1424        
   BASERLHI $ 1425          ADCL_B1 $ 1426           ADCL_B2 $ 1427        
   ADCL_B3 $ 1428           ADCL_BHI $ 1429          ADCL_C1 $ 1430        
   ADCL_C2 $ 1431           ADCL_C3 $ 1432           ADCL_CHI $ 1433       
   ADCL_D1 $ 1434           ADCL_D2 $ 1435           ADCL_D3 $ 1436        
   ADCL_DHI $ 1437          ADCL_E1 $ 1438           ADCL_E2 $ 1439        
   ADCL_E3 $ 1440           ADCL_EHI $ 1441          ADCL_F1 $ 1442        
   ADCL_F2 $ 1443           ADCL_F3 $ 1444           ADCL_FHI $ 1445       
   ADCL_G1 $ 1446           ADCL_G2 $ 1447           ADCL_G3 $ 1448        
   ADCL_GHI $ 1449          ADCL_H1 $ 1450           ADCL_H2 $ 1451        
   ADCL_H3 $ 1452           ADCL_HHI $ 1453          ADCL_I1 $ 1454        
   ADCL_I2 $ 1455           ADCL_I3 $ 1456           ADCL_IHI $ 1457       
   ADCL_J1 $ 1458           ADCL_J2 $ 1459           ADCL_J3 $ 1460        
   ADCL_JHI $ 1461          ADCL_K1 $ 1462           ADCL_K2 $ 1463        
   ADCL_K3 $ 1464           ADCL_KHI $ 1465          ADCL_L1 $ 1466        
   ADCL_L2 $ 1467           ADCL_L3 $ 1468           ADCL_LHI $ 1469       
   ADCL_M1 $ 1470           ADCL_M2 $ 1471           ADCL_M3 $ 1472        
   ADCL_MHI $ 1473          ADCL_N1 $ 1474           ADCL_N2 $ 1475        
   ADCL_N3 $ 1476           ADCL_NHI $ 1477          ADCL_O1 $ 1478        
   ADCL_O2 $ 1479           ADCL_O3 $ 1480           ADCL_OHI $ 1481       
   ADCL_P1 $ 1482           ADCL_P2 $ 1483           ADCL_P3 $ 1484        
   ADCL_PHI $ 1485          ADCL_Q1 $ 1486           ADCL_Q2 $ 1487        
   ADCL_Q3 $ 1488           ADCL_QHI $ 1489          ADCL_R1 $ 1490        
   ADCL_R2 $ 1491           ADCL_R3 $ 1492           ADCL_RHI $ 1493       
   ADCL_S1 $ 1494           ADCL_S2 $ 1495           ADCL_S3 $ 1496        
   ADCL_SHI $ 1497          ADCL_T1 $ 1498           ADCL_T2 $ 1499        
   ADCL_T3 $ 1500           ADCL_THI $ 1501          ADCL_U1 $ 1502        
   ADCL_U2 $ 1503           ADCL_U3 $ 1504           ADCL_UHI $ 1505       
   BASECL1 $ 1506           BASECL2 $ 1507           BASECL3 $ 1508        
   BASECLHI $ 1509          ADUL_B1 $ 1510           ADUL_B2 $ 1511        
   ADUL_B3 $ 1512           ADUL_BHI $ 1513          ADUL_C1 $ 1514        
   ADUL_C2 $ 1515           ADUL_C3 $ 1516           ADUL_CHI $ 1517       
   ADUL_D1 $ 1518           ADUL_D2 $ 1519           ADUL_D3 $ 1520        
   ADUL_DHI $ 1521          ADUL_E1 $ 1522           ADUL_E2 $ 1523        
   ADUL_E3 $ 1524           ADUL_EHI $ 1525          ADUL_F1 $ 1526        
   ADUL_F2 $ 1527           ADUL_F3 $ 1528           ADUL_FHI $ 1529       
   ADUL_G1 $ 1530           ADUL_G2 $ 1531           ADUL_G3 $ 1532        
   ADUL_GHI $ 1533          ADUL_H1 $ 1534           ADUL_H2 $ 1535        
   ADUL_H3 $ 1536           ADUL_HHI $ 1537          ADUL_I1 $ 1538        
   ADUL_I2 $ 1539           ADUL_I3 $ 1540           ADUL_IHI $ 1541       
   ADUL_J1 $ 1542           ADUL_J2 $ 1543           ADUL_J3 $ 1544        
   ADUL_JHI $ 1545          ADUL_K1 $ 1546           ADUL_K2 $ 1547        
   ADUL_K3 $ 1548           ADUL_KHI $ 1549          ADUL_L1 $ 1550        
   ADUL_L2 $ 1551           ADUL_L3 $ 1552           ADUL_LHI $ 1553       
   ADUL_M1 $ 1554           ADUL_M2 $ 1555           ADUL_M3 $ 1556        
   ADUL_MHI $ 1557          ADUL_N1 $ 1558           ADUL_N2 $ 1559        
   ADUL_N3 $ 1560           ADUL_NHI $ 1561          ADUL_O1 $ 1562        
   ADUL_O2 $ 1563           ADUL_O3 $ 1564           ADUL_OHI $ 1565       
   ADUL_P1 $ 1566           ADUL_P2 $ 1567           ADUL_P3 $ 1568        
   ADUL_PHI $ 1569          ADUL_Q1 $ 1570           ADUL_Q2 $ 1571        
   ADUL_Q3 $ 1572           ADUL_QHI $ 1573          ADUL_R1 $ 1574        
   ADUL_R2 $ 1575           ADUL_R3 $ 1576           ADUL_RHI $ 1577       
   ADUL_S1 $ 1578           ADUL_S2 $ 1579           ADUL_S3 $ 1580        
   ADUL_SHI $ 1581          ADUL_T1 $ 1582           ADUL_T2 $ 1583        
   ADUL_T3 $ 1584           ADUL_THI $ 1585          ADUL_U1 $ 1586        
   ADUL_U2 $ 1587           ADUL_U3 $ 1588           ADUL_UHI $ 1589       
   BASEUL1 $ 1590           BASEUL2 $ 1591           BASEUL3 $ 1592        
   BASEULHI $ 1593          GDLINE1 $ 1594-1598      GDLINE2 $ 1599-1603   
   GDLINE3 $ 1604-1608      GDSTAT1 $ 1609-1613      GDSTAT2 $ 1614-1618   
   GDSTAT3 $ 1619-1623      GDREF1 $ 1624-1628       GDREF2 $ 1629-1633    
   GDREF3 $ 1634            GDCROS1 $ 1635           GDCROS2 $ 1636        
   GDCROS3 $ 1637           GDUNDR1 $ 1638           GDUNDR2 $ 1639        
   GDUNDR3 $ 1640           GDLINEHI $ 1641-1645     GDSTATHI $ 1646-1650  
   GDREFHI $ 1651-1655      GDCROSHI $ 1656          GDUNDRHI $ 1657       
   STA1_1 $ 1658-1668       STA1_2 $ 1669-1677       STA1_3 $ 1678-1685    
   STA1_4 $ 1686-1693       STA1_5 $ 1694-1702       STA1_6 $ 1703-1711    
   STA1_7 $ 1712-1719       STA1_8 $ 1720-1727       STA1_9 $ 1728-1735    
   STA1_10 $ 1736-1743      STA1_11 $ 1744-1751      STA1_12 $ 1752-1759   
   STA1_13 $ 1760-1767      STA1_14 $ 1768-1775      STA1_15 $ 1776-1783   
   STA1_16 $ 1784-1791      STA1_17 $ 1792-1800      STA1_18 $ 1801-1809   
   STA1_19 $ 1810-1818      STA1_20 $ 1819-1827      STA1_21 $ 1828-1836   
   STA1_22 $ 1837-1844      STA1_23 $ 1845-1853      STA1_24 $ 1854-1862   
   STA1_25 $ 1863-1870      STA1_26 $ 1871-1878      STA1_27 $ 1879-1886   
   STA1_28 $ 1887-1894      STA1_29 $ 1895-1902      STA1_30 $ 1903-1910   
   STA2_1 $ 1911-1919       STA2_2 $ 1920-1927       STA2_3 $ 1928-1935    
   STA2_4 $ 1936-1943       STA2_5 $ 1944-1951       STA2_6 $ 1952-1959    
   STA2_7 $ 1960-1967       STA2_8 $ 1968-1975       STA2_9 $ 1976-1983    
   STA2_10 $ 1984-1991      STA2_11 $ 1992-1999      STA2_12 $ 2000-2007   
   STA2_13 $ 2008-2015      STA2_14 $ 2016-2023      STA2_15 $ 2024-2031   
   STA2_16 $ 2032-2039      STA2_17 $ 2040-2047      STA2_18 $ 2048-2055   
   STA2_19 $ 2056-2063      STA2_20 $ 2064-2071      STA2_21 $ 2072-2079   
   STA2_22 $ 2080-2087      STA2_23 $ 2088-2095      STA2_24 $ 2096-2103   
   STA2_25 $ 2104-2111      STA2_26 $ 2112-2119      STA2_27 $ 2120-2127   
   STA2_28 $ 2128-2135      STA2_29 $ 2136-2143      STA2_30 $ 2144-2151   
   STA3_1 $ 2152-2159       STA3_2 $ 2160-2166       STA3_3 $ 2167         
   STA3_4 $ 2168            STA3_5 $ 2169            STA3_6 $ 2170         
   STA3_7 $ 2171            STA3_8 $ 2172            STA3_9 $ 2173         
   STA3_10 $ 2174           STA3_11 $ 2175           STA3_12 $ 2176        
   STA3_13 $ 2177           STA3_14 $ 2178           STA3_15 $ 2179        
   STA3_16 $ 2180           STA3_17 $ 2181           STA3_18 $ 2182        
   STA3_19 $ 2183           STA3_20 $ 2184           STA3_21 $ 2185        
   STA3_22 $ 2186           STA3_23 $ 2187           STA3_24 $ 2188        
   STA3_25 $ 2189           STA3_26 $ 2190           STA3_27 $ 2191        
   STA3_28 $ 2192           STA3_29 $ 2193           STA3_30 $ 2194        
   NWSTAT1 $ 2195-2205      NWSTAT2 $ 2206-2214      NWSTAT3 $ 2215-2223   
   NWSTAT4 $ 2224-2232      NWSTAT5 $ 2233-2240      NWSTAT6 $ 2241-2248   
   NWSTAT7 $ 2249-2254      TTSC1_1 $ 2255-2260      TTSC1_2 $ 2261-2266   
   TTSC1_3 $ 2267-2272      TTSC1_4 $ 2273-2278      TTSC1_5 $ 2279-2284   
   TTSC1_6 $ 2285-2290      TTSC1_7 $ 2291-2296      TTSC1_8 $ 2297-2302   
   TTSC1_9 $ 2303-2308      TTSC1_10 $ 2309-2314     TTSC1_11 $ 2315-2320  
   TTSC1_12 $ 2321-2326     TTSC1_13 $ 2327-2332     TTSC1_14 $ 2333-2338  
   TTSC1_15 $ 2339-2344     TTSC1_16 $ 2345-2350     TTSC1_17 $ 2351-2356  
   TTSC1_18 $ 2357-2362     TTSC1_19 $ 2363-2368     TTSC1_20 $ 2369-2374  
   TTSC1_21 $ 2375-2380     TTSC1_22 $ 2381-2385     TTSC1_23 $ 2386-2391  
   TTSC1_24 $ 2392-2397     TTSC1_25 $ 2398-2402     TTSC1_26 $ 2403-2407  
   TTSC1_27 $ 2408-2412     TTSC1_28 $ 2413-2417     TTSC1_29 $ 2418-2422  
   TTSC1_30 $ 2423-2427     TTSC2_1 $ 2428-2435      TTSC2_2 $ 2436-2441   
   TTSC2_3 $ 2442-2447      TTSC2_4 $ 2448-2453      TTSC2_5 $ 2454-2459   
   TTSC2_6 $ 2460-2465      TTSC2_7 $ 2466-2470      TTSC2_8 $ 2471-2475   
   TTSC2_9 $ 2476-2480      TTSC2_10 $ 2481-2485     TTSC2_11 $ 2486-2490  
   TTSC2_12 $ 2491-2495     TTSC2_13 $ 2496-2500     TTSC2_14 $ 2501-2505  
   TTSC2_15 $ 2506-2510     TTSC2_16 $ 2511-2515     TTSC2_17 $ 2516-2520  
   TTSC2_18 $ 2521-2525     TTSC2_19 $ 2526-2530     TTSC2_20 $ 2531-2535  
   TTSC2_21 $ 2536-2540     TTSC2_22 $ 2541-2545     TTSC2_23 $ 2546-2550  
   TTSC2_24 $ 2551-2555     TTSC2_25 $ 2556-2560     TTSC2_26 $ 2561-2565  
   TTSC2_27 $ 2566-2570     TTSC2_28 $ 2571-2575     TTSC2_29 $ 2576-2580  
   TTSC2_30 $ 2581-2585     TTSC3_1 $ 2586-2593      TTSC3_2 $ 2594-2598   
   TTSC3_3 $ 2599           TTSC3_4 $ 2600           TTSC3_5 $ 2601        
   TTSC3_6 $ 2602           TTSC3_7 $ 2603           TTSC3_8 $ 2604        
   TTSC3_9 $ 2605           TTSC3_10 $ 2606          TTSC3_11 $ 2607       
   TTSC3_12 $ 2608          TTSC3_13 $ 2609          TTSC3_14 $ 2610       
   TTSC3_15 $ 2611          TTSC3_16 $ 2612          TTSC3_17 $ 2613       
   TTSC3_18 $ 2614          TTSC3_19 $ 2615          TTSC3_20 $ 2616       
   TTSC3_21 $ 2617          TTSC3_22 $ 2618          TTSC3_23 $ 2619       
   TTSC3_24 $ 2620          TTSC3_25 $ 2621          TTSC3_26 $ 2622       
   TTSC3_27 $ 2623          TTSC3_28 $ 2624          TTSC3_29 $ 2625       
   TTSC3_30 $ 2626          SMAX1  2627-2632         SMAX2  2633-2638      
   SMAX3  2639-2644         SMAX4  2645-2650         SMAX5  2651-2656      
   SMAX6  2657-2662         SMAX7  2663-2668         SMAX8  2669-2674      
   SMAX9  2675-2680         SMAX10  2681-2686        SMAX11  2687-2692     
   SMAX12  2693-2698        SMAX13  2699-2704        SMAX14  2705-2710     
   SMAX15  2711-2716        SMAX16  2717-2722        SMAX17  2723-2728     
   SMAX18  2729-2734        SMAX19  2735-2740        SMAX20  2741-2746     
   SMAX21  2747-2752        SMAX22  2753-2758        SMAX23  2759-2764     
   SMAX24  2765-2770        SMAX25  2771-2776        SMAX26  2777-2782     
   SMAX27  2783-2788        SMAX28  2789-2794        SMAX29  2795-2800     
   SMAX30  2801-2806        SMIN1  2807              SMIN2  2808           
   SMIN3  2809              SMIN4  2810              SMIN5  2811           
   SMIN6  2812              SMIN7  2813              SMIN8  2814           
   SMIN9  2815              SMIN10  2816             SMIN11  2817          
   SMIN12  2818             SMIN13  2819             SMIN14  2820          
   SMIN15  2821             SMIN16  2822             SMIN17  2823          
   SMIN18  2824             SMIN19  2825             SMIN20  2826          
   SMIN21  2827             SMIN22  2828             SMIN23  2829          
   SMIN24  2830             SMIN25  2831             SMIN26  2832          
   SMIN27  2833             SMIN28  2834             SMIN29  2835          
   SMIN30  2836             RETEXT1 $ 2837-2883      RETEXT2 $ 2884        
   RETEXT3 $ 2885         ;                       

LENGTH
   ACCEPT 3                 BUSCLAS 4                CANTPAY 3             
   CCULPSCO 3               CH2APP 3                 CH8FINGD 3            
   CMSRVORD 3               COFI 3                   COMPLY 3              
   COMPLYPR 3               CRIMPURP 3               DETBFINE 3            
   DISPOSIT 3               EMPLOYNM 3               FCULPSCO 3            
   FRAUDTYP 3               FINSTDS 3                HISTORY 3             
   HSMISCND 3               INCORLOC 3               INCORPYR 4            
   INDICT 3                 INPLEA1 3                INPLEA2 3             
   INPLEA3 3                INPLEA4 3                INPLEA5 3             
   INPLEA6 3                INPLEA7 3                INPLEA8 3             
   INPLEA9 3                INPLEA10 3               INPLEA11 3            
   INPLEA12 3               INNOPL1 3                INNOPL2 3             
   INNOPL3 3                INNOPL4 3                INNOPL5 3             
   INNOPL6 3                INNOPL7 3                INNOPL8 3             
   INNOPL9 3                INNOPL10 3               INNOPL11 3            
   INNOPL12 3               JANDC 3                  NEWCNVTN 3            
   NOCOMP 3                 NOCOUNTS 3               NOREAVAR 3            
   NOUSTAT 3                OBSTRUCT 3               OFFLVL 3              
   ORDERCE 3                OWNSTRCT 3               PLEA 3                
   PRIMOFF 3                PRCIVIL 3                PRCRIME 3             
   PROBATN 3                PROBMON 3                PSR 3                 
   QUARTER 3                REAS1 4                  REAS2 3               
   REAS3 3                  REASON2 3                REASON3 3             
   REASON4 3                REASONS 3                REMEDORD 3            
   SELFREP 3                SENTRNGE 3               TOLERNCE 3            
   TYPEOTHS 3               VICTNOTE 3               VIOLATE 3             
   AMENDYR 4                SENTYR 4                 BASEFINE 6            
   COSTASSM 4               DISGORGE 3               FINOFFST 3            
   FORFEITR 6               GLFINMAX 6               GLFINMIN 6            
   STATMIN 3                STATMAX 6                RESTCAT 3             
   FINECAT 3                SUSFNCAT 3               LCAT1 3               
   LCAT2 3                  LCAT3 3                  LCATHI 3              
   LCATS1 3                 LCATS2 3                 LCATS3 3              
   LCATSHI 3                LCATR1 3                 LCATR2 3              
   LCATR3 3                 LCATRHI 3                LCATC1 3              
   LCATC2 3                 LCATC3 3                 LCATCHI 3             
   LCATU1 3                 LCATU2 3                 LCATU3 3              
   LCATUHI 3                CPIDN 6                  ADJOFL1 3             
   ADJOFL2 3                ADJOFL3 3                ADJOFLHI 3            
   ADJ_B1 3                 ADJ_B2 3                 ADJ_B3 3              
   ADJ_BHI 3                ADJ_C1 3                 ADJ_C2 3              
   ADJ_C3 3                 ADJ_CHI 3                ADJ_D1 3              
   ADJ_D2 3                 ADJ_D3 3                 ADJ_DHI 3             
   ADJ_E1 3                 ADJ_E2 3                 ADJ_E3 3              
   ADJ_EHI 3                ADJ_F1 3                 ADJ_F2 3              
   ADJ_F3 3                 ADJ_FHI 3                ADJ_G1 3              
   ADJ_G2 3                 ADJ_G3 3                 ADJ_GHI 3             
   ADJ_H1 3                 ADJ_H2 3                 ADJ_H3 3              
   ADJ_HHI 3                ADJ_I1 3                 ADJ_I2 3              
   ADJ_I3 3                 ADJ_IHI 3                ADJ_J1 3              
   ADJ_J2 3                 ADJ_J3 3                 ADJ_JHI 3             
   ADJ_K1 3                 ADJ_K2 3                 ADJ_K3 3              
   ADJ_KHI 3                ADJ_L1 3                 ADJ_L2 3              
   ADJ_L3 3                 ADJ_LHI 3                ADJ_M1 3              
   ADJ_M2 3                 ADJ_M3 3                 ADJ_MHI 3             
   ADJ_N1 3                 ADJ_N2 3                 ADJ_N3 3              
   ADJ_NHI 3                ADJ_O1 3                 ADJ_O2 3              
   ADJ_O3 3                 ADJ_OHI 3                ADJ_P1 3              
   ADJ_P2 3                 ADJ_P3 3                 ADJ_PHI 3             
   ADJ_Q1 3                 ADJ_Q2 3                 ADJ_Q3 3              
   ADJ_QHI 3                ADJ_R1 3                 ADJ_R2 3              
   ADJ_R3 3                 ADJ_RHI 3                ADJ_S1 3              
   ADJ_S2 3                 ADJ_S3 3                 ADJ_SHI 3             
   ADJ_T1 3                 ADJ_T2 3                 ADJ_T3 3              
   ADJ_THI 3                ADJ_U1 3                 ADJ_U2 3              
   ADJ_U3 3                 ADJ_UHI 3                BASADJ1 3             
   BASADJ2 3                BASADJ3 3                BASADJHI 3            
   BASE1 3                  BASE2 3                  BASE3 3               
   BASEHI 3                 BASLN1 3                 BASLN2 3              
   BASLN3 3                 BASLNHI 3                ADJOFS1 3             
   ADJOFS2 3                ADJOFS3 3                ADJOFSHI 3            
   ADJS_B1 3                ADJS_B2 3                ADJS_B3 3             
   ADJS_BHI 3               ADJS_C1 3                ADJS_C2 3             
   ADJS_C3 3                ADJS_CHI 3               ADJS_D1 3             
   ADJS_D2 3                ADJS_D3 3                ADJS_DHI 3            
   ADJS_E1 3                ADJS_E2 3                ADJS_E3 3             
   ADJS_EHI 3               ADJS_F1 3                ADJS_F2 3             
   ADJS_F3 3                ADJS_FHI 3               ADJS_G1 3             
   ADJS_G2 3                ADJS_G3 3                ADJS_GHI 3            
   ADJS_H1 3                ADJS_H2 3                ADJS_H3 3             
   ADJS_HHI 3               ADJS_I1 3                ADJS_I2 3             
   ADJS_I3 3                ADJS_IHI 3               ADJS_J1 3             
   ADJS_J2 3                ADJS_J3 3                ADJS_JHI 3            
   ADJS_K1 3                ADJS_K2 3                ADJS_K3 3             
   ADJS_KHI 3               ADJS_L1 3                ADJS_L2 3             
   ADJS_L3 3                ADJS_LHI 3               ADJS_M1 3             
   ADJS_M2 3                ADJS_M3 3                ADJS_MHI 3            
   ADJS_N1 3                ADJS_N2 3                ADJS_N3 3             
   ADJS_NHI 3               ADJS_O1 3                ADJS_O2 3             
   ADJS_O3 3                ADJS_OHI 3               ADJS_P1 3             
   ADJS_P2 3                ADJS_P3 3                ADJS_PHI 3            
   ADJS_Q1 3                ADJS_Q2 3                ADJS_Q3 3             
   ADJS_QHI 3               ADJS_R1 3                ADJS_R2 3             
   ADJS_R3 3                ADJS_RHI 3               ADJS_S1 3             
   ADJS_S2 3                ADJS_S3 3                ADJS_SHI 3            
   ADJS_T1 3                ADJS_T2 3                ADJS_T3 3             
   ADJS_THI 3               ADJS_U1 3                ADJS_U2 3             
   ADJS_U3 3                ADJS_UHI 3               BASADS1 3             
   BASADS2 3                BASADS3 3                BASADSHI 3            
   BASES1 3                 BASES2 3                 BASES3 3              
   BASESHI 3                BASLNS1 3                BASLNS2 3             
   BASLNS3 3                BASLNSHI 3               ADJOFR1 3             
   ADJOFR2 3                ADJOFR3 3                ADJOFRHI 3            
   ADJR_B1 3                ADJR_B2 3                ADJR_B3 3             
   ADJR_BHI 3               ADJR_C1 3                ADJR_C2 3             
   ADJR_C3 3                ADJR_CHI 3               ADJR_D1 3             
   ADJR_D2 3                ADJR_D3 3                ADJR_DHI 3            
   ADJR_E1 3                ADJR_E2 3                ADJR_E3 3             
   ADJR_EHI 3               ADJR_F1 3                ADJR_F2 3             
   ADJR_F3 3                ADJR_FHI 3               ADJR_G1 3             
   ADJR_G2 3                ADJR_G3 3                ADJR_GHI 3            
   ADJR_H1 3                ADJR_H2 3                ADJR_H3 3             
   ADJR_HHI 3               ADJR_I1 3                ADJR_I2 3             
   ADJR_I3 3                ADJR_IHI 3               ADJR_J1 3             
   ADJR_J2 3                ADJR_J3 3                ADJR_JHI 3            
   ADJR_K1 3                ADJR_K2 3                ADJR_K3 3             
   ADJR_KHI 3               ADJR_L1 3                ADJR_L2 3             
   ADJR_L3 3                ADJR_LHI 3               ADJR_M1 3             
   ADJR_M2 3                ADJR_M3 3                ADJR_MHI 3            
   ADJR_N1 3                ADJR_N2 3                ADJR_N3 3             
   ADJR_NHI 3               ADJR_O1 3                ADJR_O2 3             
   ADJR_O3 3                ADJR_OHI 3               ADJR_P1 3             
   ADJR_P2 3                ADJR_P3 3                ADJR_PHI 3            
   ADJR_Q1 3                ADJR_Q2 3                ADJR_Q3 3             
   ADJR_QHI 3               ADJR_R1 3                ADJR_R2 3             
   ADJR_R3 3                ADJR_RHI 3               ADJR_S1 3             
   ADJR_S2 3                ADJR_S3 3                ADJR_SHI 3            
   ADJR_T1 3                ADJR_T2 3                ADJR_T3 3             
   ADJR_THI 3               ADJR_U1 3                ADJR_U2 3             
   ADJR_U3 3                ADJR_UHI 3               BASADR1 3             
   BASADR2 3                BASADR3 3                BASADRHI 3            
   BASER1 3                 BASER2 3                 BASER3 3              
   BASERHI 3                BASLNR1 3                BASLNR2 3             
   BASLNR3 3                BASLNRHI 3               ADJOFC1 3             
   ADJOFC2 3                ADJOFC3 3                ADJOFCHI 3            
   ADJC_B1 3                ADJC_B2 3                ADJC_B3 3             
   ADJC_BHI 3               ADJC_C1 3                ADJC_C2 3             
   ADJC_C3 3                ADJC_CHI 3               ADJC_D1 3             
   ADJC_D2 3                ADJC_D3 3                ADJC_DHI 3            
   ADJC_E1 3                ADJC_E2 3                ADJC_E3 3             
   ADJC_EHI 3               ADJC_F1 3                ADJC_F2 3             
   ADJC_F3 3                ADJC_FHI 3               ADJC_G1 3             
   ADJC_G2 3                ADJC_G3 3                ADJC_GHI 3            
   ADJC_H1 3                ADJC_H2 3                ADJC_H3 3             
   ADJC_HHI 3               ADJC_I1 3                ADJC_I2 3             
   ADJC_I3 3                ADJC_IHI 3               ADJC_J1 3             
   ADJC_J2 3                ADJC_J3 3                ADJC_JHI 3            
   ADJC_K1 3                ADJC_K2 3                ADJC_K3 3             
   ADJC_KHI 3               ADJC_L1 3                ADJC_L2 3             
   ADJC_L3 3                ADJC_LHI 3               ADJC_M1 3             
   ADJC_M2 3                ADJC_M3 3                ADJC_MHI 3            
   ADJC_N1 3                ADJC_N2 3                ADJC_N3 3             
   ADJC_NHI 3               ADJC_O1 3                ADJC_O2 3             
   ADJC_O3 3                ADJC_OHI 3               ADJC_P1 3             
   ADJC_P2 3                ADJC_P3 3                ADJC_PHI 3            
   ADJC_Q1 3                ADJC_Q2 3                ADJC_Q3 3             
   ADJC_QHI 3               ADJC_R1 3                ADJC_R2 3             
   ADJC_R3 3                ADJC_RHI 3               ADJC_S1 3             
   ADJC_S2 3                ADJC_S3 3                ADJC_SHI 3            
   ADJC_T1 3                ADJC_T2 3                ADJC_T3 3             
   ADJC_THI 3               ADJC_U1 3                ADJC_U2 3             
   ADJC_U3 3                ADJC_UHI 3               BASADC1 3             
   BASADC2 3                BASADC3 3                BASADCHI 3            
   BASEC1 3                 BASEC2 3                 BASEC3 3              
   BASECHI 3                BASLNC1 3                BASLNC2 3             
   BASLNC3 3                BASLNCHI 3               ADJOFU1 3             
   ADJOFU2 3                ADJOFU3 3                ADJOFUHI 3            
   ADJU_B1 3                ADJU_B2 3                ADJU_B3 3             
   ADJU_BHI 3               ADJU_C1 3                ADJU_C2 3             
   ADJU_C3 3                ADJU_CHI 3               ADJU_D1 3             
   ADJU_D2 3                ADJU_D3 3                ADJU_DHI 3            
   ADJU_E1 3                ADJU_E2 3                ADJU_E3 3             
   ADJU_EHI 3               ADJU_F1 3                ADJU_F2 3             
   ADJU_F3 3                ADJU_FHI 3               ADJU_G1 3             
   ADJU_G2 3                ADJU_G3 3                ADJU_GHI 3            
   ADJU_H1 3                ADJU_H2 3                ADJU_H3 3             
   ADJU_HHI 3               ADJU_I1 3                ADJU_I2 3             
   ADJU_I3 3                ADJU_IHI 3               ADJU_J1 3             
   ADJU_J2 3                ADJU_J3 3                ADJU_JHI 3            
   ADJU_K1 3                ADJU_K2 3                ADJU_K3 3             
   ADJU_KHI 3               ADJU_L1 3                ADJU_L2 3             
   ADJU_L3 3                ADJU_LHI 3               ADJU_M1 3             
   ADJU_M2 3                ADJU_M3 3                ADJU_MHI 3            
   ADJU_N1 3                ADJU_N2 3                ADJU_N3 3             
   ADJU_NHI 3               ADJU_O1 3                ADJU_O2 3             
   ADJU_O3 3                ADJU_OHI 3               ADJU_P1 3             
   ADJU_P2 3                ADJU_P3 3                ADJU_PHI 3            
   ADJU_Q1 3                ADJU_Q2 3                ADJU_Q3 3             
   ADJU_QHI 3               ADJU_R1 3                ADJU_R2 3             
   ADJU_R3 3                ADJU_RHI 3               ADJU_S1 3             
   ADJU_S2 3                ADJU_S3 3                ADJU_SHI 3            
   ADJU_T1 3                ADJU_T2 3                ADJU_T3 3             
   ADJU_THI 3               ADJU_U1 3                ADJU_U2 3             
   ADJU_U3 3                ADJU_UHI 3               BASADU1 3             
   BASADU2 3                BASADU3 3                BASADUHI 3            
   BASEU1 3                 BASEU2 3                 BASEU3 3              
   BASEUHI 3                BASLNU1 3                BASLNU2 3             
   BASLNU3 3                BASLNUHI 3               SMAX1 6               
   SMAX2 6                  SMAX3 6                  SMAX4 6               
   SMAX5 6                  SMAX6 6                  SMAX7 6               
   SMAX8 6                  SMAX9 6                  SMAX10 6              
   SMAX11 6                 SMAX12 6                 SMAX13 6              
   SMAX14 6                 SMAX15 6                 SMAX16 6              
   SMAX17 6                 SMAX18 6                 SMAX19 6              
   SMAX20 6                 SMAX21 6                 SMAX22 6              
   SMAX23 6                 SMAX24 6                 SMAX25 6              
   SMAX26 6                 SMAX27 6                 SMAX28 6              
   SMAX29 6                 SMAX30 6                 SMIN1 3               
   SMIN2 3                  SMIN3 3                  SMIN4 3               
   SMIN5 3                  SMIN6 3                  SMIN7 3               
   SMIN8 3                  SMIN9 3                  SMIN10 3              
   SMIN11 3                 SMIN12 3                 SMIN13 3              
   SMIN14 3                 SMIN15 3                 SMIN16 3              
   SMIN17 3                 SMIN18 3                 SMIN19 3              
   SMIN20 3                 SMIN21 3                 SMIN22 3              
   SMIN23 3                 SMIN24 3                 SMIN25 3              
   SMIN26 3                 SMIN27 3                 SMIN28 3              
   SMIN29 3                 SMIN30 3 ;

          

RUN ;
